@@ -50,14 +50,20 @@ class CommandManipulator:
 
             if show_output:
                 outs, errs = proc.communicate(timeout=15)
-                outs_str = outs.decode('utf-8')
+                try:
+                    outs_str = outs.decode('utf-8')
+                except:
+                    outs_str = outs
                 print("Output:")
                 print(outs_str.split("Mode")[0])
 
             return True
 
         print(temp % 'x', end=': ')
-        print(proc.stderr.read().decode('utf-8'), end='')
+        try:
+            print(proc.stderr.read().decode('utf-8'), end='')
+        except:
+            print(proc.stderr.read(), end='')
 
         if die:
             raise SystemExit(proc.returncode)
